==> blesta-5.10.2.zip: blesta/plugins/domains/language/ro_ro/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- Alegeți Automatically --';
$lang['AdminMain.edit.title_basic_options'] = 'Opțiuni de bază';
$lang['AdminMain.edit.title_actions'] = 'Acțiuni';
$lang['AdminMain.edit.title_domain_information'] = 'Informații despre domeniu';
$lang['AdminMain.edit.term_years'] = '%1$s Ani';
$lang['AdminMain.edit.term_year'] = 'Anul %1$s';
$lang['AdminMain.edit.term_months'] = '%1$s Luni';
$lang['AdminMain.edit.term_month'] = '%1$s Luna';
$lang['AdminMain.edit.term_weeks'] = '%1$s Săptămâni';
$lang['AdminMain.edit.term_week'] = 'Săptămâna %1$s';
$lang['AdminMain.edit.term_days'] = '%1$s Zile';
$lang['AdminMain.edit.term_day'] = 'Ziua %1$s';
$lang['AdminMain.edit.text_date_canceled'] = 'Data anulării:';
$lang['AdminMain.edit.text_date_suspended'] = 'Data suspendării:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Data ultimei reînnoiri:';
$lang['AdminMain.edit.text_never'] = 'Niciodată';
$lang['AdminMain.edit.text_date_expires'] = 'Data expirării:';
$lang['AdminMain.edit.text_date_renews'] = 'Data se reînnoiește:';
$lang['AdminMain.edit.text_date_added'] = 'Data creării:';
$lang['AdminMain.edit.text_status'] = 'Stare:';
$lang['AdminMain.edit.text_years'] = 'Ani înregistrați:';
$lang['AdminMain.edit.text_registrar'] = 'Registrator:';
$lang['AdminMain.edit.text_domain'] = 'Domeniu:';
$lang['AdminMain.edit.field_edit_service'] = 'Editarea serviciului';
$lang['AdminMain.edit.field_activate'] = 'Activați';
$lang['AdminMain.edit.field_submit'] = 'Actualizare';
$lang['AdminMain.edit.field_notify_order'] = 'Trimiteți un e-mail de confirmare a comenzii atunci când este activat';
$lang['AdminMain.edit.field_use_module'] = 'Modul de utilizare';
$lang['AdminMain.edit.field_module'] = 'Modul registrator';
$lang['AdminMain.edit.field_client'] = 'Client';
$lang['AdminMain.edit.field_ns5'] = 'Server de nume 5';
$lang['AdminMain.edit.field_ns4'] = 'Server de nume 4';
$lang['AdminMain.edit.field_ns3'] = 'Server de nume 3';
$lang['AdminMain.edit.field_ns2'] = 'Server de nume 2';
$lang['AdminMain.edit.field_ns1'] = 'Nume de server 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Activați reînnoirea automată';
$lang['AdminMain.edit.field_years'] = 'Ani';
$lang['AdminMain.edit.field_action'] = 'Acțiune';
$lang['AdminMain.edit.link_viewclient'] = 'Vezi clientul';
$lang['AdminMain.edit.boxtitle_edit'] = 'Editare domeniu: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Client #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Reducere:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Subtotal:';
$lang['AdminMain.add_confirmation.price'] = 'Preț';
$lang['AdminMain.add_confirmation.qty'] = 'Cantitate';
$lang['AdminMain.add_confirmation.description'] = 'Descriere';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Transfer';
$lang['AdminMain.add_confirmation.type_register'] = 'Înregistrare';
$lang['AdminMain.add_confirmation.field_edit'] = 'Editați';
$lang['AdminMain.add_confirmation.field_add'] = 'Adăugați un domeniu';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Actualizare';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Cod cupon';
$lang['AdminMain.add_confirmation.field_price'] = 'Preț:';
$lang['AdminMain.add_confirmation.field_type'] = 'Tip:';
$lang['AdminMain.add_confirmation.field_years'] = 'Ani:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domeniu:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Nu';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Da';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Trimiteți e-mailul de confirmare a comenzii:';
$lang['AdminMain.add_confirmation.field_module'] = 'Modulul Registrator:';
$lang['AdminMain.add_confirmation.field_status'] = 'Stare:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Nu facturați';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Adăugați la factură %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Creați o factură nouă';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Metoda de facturare:';
$lang['AdminMain.add.edit_package_pricing'] = 'Editați prețurile';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (se reînnoiește @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Comandă selectată';
$lang['AdminMain.add.term_years'] = '%1$s Ani';
$lang['AdminMain.add.term_year'] = 'Anul %1$s';
$lang['AdminMain.add.term_months'] = '%1$s Luni';
$lang['AdminMain.add.term_month'] = '%1$s Luna';
$lang['AdminMain.add.term_weeks'] = '%1$s Săptămâni';
$lang['AdminMain.add.term_week'] = 'Săptămâna %1$s';
$lang['AdminMain.add.term_days'] = '%1$s Zile';
$lang['AdminMain.add.term_day'] = 'Ziua %1$s';
$lang['AdminMain.add.text_domain_unavailable'] = 'Indisponibil';
$lang['AdminMain.add.text_domain_available'] = 'Disponibil';
$lang['AdminMain.add.heading_options'] = 'Opțiuni';
$lang['AdminMain.add.heading_status'] = 'Stare';
$lang['AdminMain.add.heading_domain'] = 'Domeniu';
$lang['AdminMain.add.title_registrar_options'] = 'Opțiuni de înregistrare';
$lang['AdminMain.add.title_basic_options'] = 'Opțiuni de bază';
$lang['AdminMain.add.title_search_results'] = 'Rezultatele căutării';
$lang['AdminMain.add.field_notify_order'] = 'Trimiteți un e-mail de confirmare a comenzii atunci când este activat';
$lang['AdminMain.add.field_use_module'] = 'Aprovizionarea domeniului cu ajutorul modulului de înregistrare atunci când este activat';
$lang['AdminMain.add.field_module'] = 'Modul registrator';
$lang['AdminMain.add.field_status'] = 'Stare';
$lang['AdminMain.add.field_years'] = 'Ani';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Nu facturați';
$lang['AdminMain.add.field_invoice_method_append'] = 'Adăugare la factura existentă';
$lang['AdminMain.add.field_invoice_method_create'] = 'Creați o factură nouă';
$lang['AdminMain.add.field_invoice_method'] = 'Metoda de facturare';
$lang['AdminMain.add.field_submit'] = 'Continuați';
$lang['AdminMain.add.field_lookup'] = 'Verificați disponibilitatea';
$lang['AdminMain.add.field_add'] = 'Adăugați un domeniu';
$lang['AdminMain.add.field_register'] = 'Înregistrare';
$lang['AdminMain.add.field_transfer'] = 'Transfer';
$lang['AdminMain.add.link_viewclient'] = 'Vezi clientul';
$lang['AdminMain.add.boxtitle_add'] = 'Adăugați domeniu: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Client #%1$s';
$lang['AdminMain.index.unparent'] = 'Unparent și Reset Preț';
$lang['AdminMain.!error.unsupported_domain'] = 'Numele de domeniu nu este acceptat.';
$lang['AdminMain.!success.service_edited'] = 'Domeniul a fost actualizat cu succes!';
$lang['AdminMain.!success.domain_add'] = 'Domeniul a fost adăugat cu succes!';
$lang['AdminMain.!success.domain_transfer'] = 'Domeniul a fost transferat cu succes!';
$lang['AdminMain.!success.domain_register'] = 'Domeniul a fost înregistrat cu succes!';
$lang['AdminMain.!success.domains_unparented'] = 'Domeniile selectate au fost eliminate din serviciile lor părintești și prețul a fost resetat cu succes!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nume de domeniu';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Orice';
$lang['AdminMain.domains.action.field_client'] = 'Client';
$lang['AdminMain.domains.action.field_nameservers'] = 'Nameservere';
$lang['AdminMain.domains.action.field_years'] = 'Ani';
$lang['AdminMain.index.field_actionsubmit'] = 'Trimiteți';
$lang['AdminMain.index.domain_push_to_client'] = 'Push to Client';
$lang['AdminMain.index.update_nameservers'] = 'Actualizarea Nameserverelor';
$lang['AdminMain.index.domain_renewal'] = 'Reînnoiți domeniul';
$lang['AdminMain.index.change_auto_renewal'] = 'Schimbarea reînnoirii auto';
$lang['AdminMain.index.text_off'] = 'Off';
$lang['AdminMain.index.text_on'] = 'Pe';
$lang['AdminMain.index.text_never'] = 'Niciodată';
$lang['AdminMain.index.no_results'] = 'Nu există servicii cu acest statut.';
$lang['AdminMain.index.confirm_delete'] = 'Sunteți sigur că doriți să ștergeți acest serviciu?';
$lang['AdminMain.index.option_delete'] = 'Ștergeți';
$lang['AdminMain.index.option_manage'] = 'Gestionați';
$lang['AdminMain.index.option_parent'] = 'Părinte';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Domeniu nou';
$lang['AdminMain.index.category_canceled'] = 'Anulat';
$lang['AdminMain.index.category_suspended'] = 'Suspendat';
$lang['AdminMain.index.category_pending'] = 'În așteptare';
$lang['AdminMain.index.category_active'] = 'Activ';
$lang['AdminMain.index.heading_options'] = 'Opțiuni';
$lang['AdminMain.index.heading_datecanceled'] = 'Data anulării';
$lang['AdminMain.index.heading_datesuspended'] = 'Data suspendării';
$lang['AdminMain.index.heading_dateexpires'] = 'Data expirării';
$lang['AdminMain.index.heading_daterenews'] = 'Data reînnoiește';
$lang['AdminMain.index.heading_datecreated'] = 'Data creării';
$lang['AdminMain.index.heading_term'] = 'Termen';
$lang['AdminMain.index.heading_domain'] = 'Domeniu';
$lang['AdminMain.index.heading_status'] = 'Stare';
$lang['AdminMain.index.heading_addons'] = 'Suplimente';
$lang['AdminMain.index.boxtitle_domains'] = 'Domenii';
$lang['AdminMain.index.page_title'] = 'Client #%1$s Domenii';
$lang['AdminMain.!success.domains_pushed'] = 'Domeniile selectate au fost transferate cu succes către noul client.';
$lang['AdminMain.!success.update_nameservers'] = 'Serverele de nume de domeniu au fost actualizate!';
$lang['AdminMain.!success.domain_renewal'] = 'Domeniul a fost reînnoit!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Reînnoirea automată a domeniului a fost actualizată!';
$lang['AdminMain.edit.text_registration_date'] = 'Data înregistrării:';
$lang['AdminMain.index.text_date_added'] = 'Data adăugării:';
$lang['AdminMain.index.heading_dateregistration'] = 'Data înregistrării';
$lang['AdminMain.index.heading_registrar'] = 'Registrator';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Registrul de domenii a fost actualizat!';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/ro_ro/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- Alegeți Automatically --';
$lang['AdminMain.edit.title_basic_options'] = 'Opțiuni de bază';
$lang['AdminMain.edit.title_actions'] = 'Acțiuni';
$lang['AdminMain.edit.title_domain_information'] = 'Informații despre domeniu';
$lang['AdminMain.edit.term_years'] = '%1$s Ani';
$lang['AdminMain.edit.term_year'] = 'Anul %1$s';
$lang['AdminMain.edit.term_months'] = '%1$s Luni';
$lang['AdminMain.edit.term_month'] = '%1$s Luna';
$lang['AdminMain.edit.term_weeks'] = '%1$s Săptămâni';
$lang['AdminMain.edit.term_week'] = 'Săptămâna %1$s';
$lang['AdminMain.edit.term_days'] = '%1$s Zile';
$lang['AdminMain.edit.term_day'] = 'Ziua %1$s';
$lang['AdminMain.edit.text_date_canceled'] = 'Data anulării:';
$lang['AdminMain.edit.text_date_suspended'] = 'Data suspendării:';
$lang['AdminMain.edit.text_date_last_renewed'] = 'Data ultimei reînnoiri:';
$lang['AdminMain.edit.text_never'] = 'Niciodată';
$lang['AdminMain.edit.text_date_expires'] = 'Data expirării:';
$lang['AdminMain.edit.text_date_renews'] = 'Data se reînnoiește:';
$lang['AdminMain.edit.text_date_added'] = 'Data creării:';
$lang['AdminMain.edit.text_status'] = 'Stare:';
$lang['AdminMain.edit.text_years'] = 'Ani înregistrați:';
$lang['AdminMain.edit.text_registrar'] = 'Registrator:';
$lang['AdminMain.edit.text_domain'] = 'Domeniu:';
$lang['AdminMain.edit.field_edit_service'] = 'Editarea serviciului';
$lang['AdminMain.edit.field_activate'] = 'Activați';
$lang['AdminMain.edit.field_submit'] = 'Actualizare';
$lang['AdminMain.edit.field_notify_order'] = 'Trimiteți un e-mail de confirmare a comenzii atunci când este activat';
$lang['AdminMain.edit.field_use_module'] = 'Modul de utilizare';
$lang['AdminMain.edit.field_module'] = 'Modul registrator';
$lang['AdminMain.edit.field_client'] = 'Client';
$lang['AdminMain.edit.field_ns5'] = 'Server de nume 5';
$lang['AdminMain.edit.field_ns4'] = 'Server de nume 4';
$lang['AdminMain.edit.field_ns3'] = 'Server de nume 3';
$lang['AdminMain.edit.field_ns2'] = 'Server de nume 2';
$lang['AdminMain.edit.field_ns1'] = 'Nume de server 1';
$lang['AdminMain.edit.field_auto_renewal'] = 'Activați reînnoirea automată';
$lang['AdminMain.edit.field_years'] = 'Ani';
$lang['AdminMain.edit.field_action'] = 'Acțiune';
$lang['AdminMain.edit.link_viewclient'] = 'Vezi clientul';
$lang['AdminMain.edit.boxtitle_edit'] = 'Editare domeniu: %1$s';
$lang['AdminMain.edit.boxtitle_client'] = 'Client #%1$s';
$lang['AdminMain.add_confirmation.discount'] = 'Reducere:';
$lang['AdminMain.add_confirmation.subtotal'] = 'Subtotal:';
$lang['AdminMain.add_confirmation.price'] = 'Preț';
$lang['AdminMain.add_confirmation.qty'] = 'Cantitate';
$lang['AdminMain.add_confirmation.description'] = 'Descriere';
$lang['AdminMain.add_confirmation.type_transfer'] = 'Transfer';
$lang['AdminMain.add_confirmation.type_register'] = 'Înregistrare';
$lang['AdminMain.add_confirmation.field_edit'] = 'Editați';
$lang['AdminMain.add_confirmation.field_add'] = 'Adăugați un domeniu';
$lang['AdminMain.add_confirmation.field_update_coupon'] = 'Actualizare';
$lang['AdminMain.add_confirmation.field_coupon_code'] = 'Cod cupon';
$lang['AdminMain.add_confirmation.field_price'] = 'Preț:';
$lang['AdminMain.add_confirmation.field_type'] = 'Tip:';
$lang['AdminMain.add_confirmation.field_years'] = 'Ani:';
$lang['AdminMain.add_confirmation.field_domain'] = 'Domeniu:';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = 'Nu';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = 'Da';
$lang['AdminMain.add_confirmation.field_notify_order'] = 'Trimiteți e-mailul de confirmare a comenzii:';
$lang['AdminMain.add_confirmation.field_module'] = 'Modulul Registrator:';
$lang['AdminMain.add_confirmation.field_status'] = 'Stare:';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = 'Nu facturați';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = 'Adăugați la factură %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = 'Creați o factură nouă';
$lang['AdminMain.add_confirmation.field_invoice_method'] = 'Metoda de facturare:';
$lang['AdminMain.add.edit_package_pricing'] = 'Editați prețurile';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s (se reînnoiește @ %3$s)';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = 'Comandă selectată';
$lang['AdminMain.add.term_years'] = '%1$s Ani';
$lang['AdminMain.add.term_year'] = 'Anul %1$s';
$lang['AdminMain.add.term_months'] = '%1$s Luni';
$lang['AdminMain.add.term_month'] = '%1$s Luna';
$lang['AdminMain.add.term_weeks'] = '%1$s Săptămâni';
$lang['AdminMain.add.term_week'] = 'Săptămâna %1$s';
$lang['AdminMain.add.term_days'] = '%1$s Zile';
$lang['AdminMain.add.term_day'] = 'Ziua %1$s';
$lang['AdminMain.add.text_domain_unavailable'] = 'Indisponibil';
$lang['AdminMain.add.text_domain_available'] = 'Disponibil';
$lang['AdminMain.add.heading_options'] = 'Opțiuni';
$lang['AdminMain.add.heading_status'] = 'Stare';
$lang['AdminMain.add.heading_domain'] = 'Domeniu';
$lang['AdminMain.add.title_registrar_options'] = 'Opțiuni de înregistrare';
$lang['AdminMain.add.title_basic_options'] = 'Opțiuni de bază';
$lang['AdminMain.add.title_search_results'] = 'Rezultatele căutării';
$lang['AdminMain.add.field_notify_order'] = 'Trimiteți un e-mail de confirmare a comenzii atunci când este activat';
$lang['AdminMain.add.field_use_module'] = 'Aprovizionarea domeniului cu ajutorul modulului de înregistrare atunci când este activat';
$lang['AdminMain.add.field_module'] = 'Modul registrator';
$lang['AdminMain.add.field_status'] = 'Stare';
$lang['AdminMain.add.field_years'] = 'Ani';
$lang['AdminMain.add.field_invoice_method_dont'] = 'Nu facturați';
$lang['AdminMain.add.field_invoice_method_append'] = 'Adăugare la factura existentă';
$lang['AdminMain.add.field_invoice_method_create'] = 'Creați o factură nouă';
$lang['AdminMain.add.field_invoice_method'] = 'Metoda de facturare';
$lang['AdminMain.add.field_submit'] = 'Continuați';
$lang['AdminMain.add.field_lookup'] = 'Verificați disponibilitatea';
$lang['AdminMain.add.field_add'] = 'Adăugați un domeniu';
$lang['AdminMain.add.field_register'] = 'Înregistrare';
$lang['AdminMain.add.field_transfer'] = 'Transfer';
$lang['AdminMain.add.link_viewclient'] = 'Vezi clientul';
$lang['AdminMain.add.boxtitle_add'] = 'Adăugați domeniu: %1$s';
$lang['AdminMain.add.boxtitle_client'] = 'Client #%1$s';
$lang['AdminMain.index.unparent'] = 'Unparent și Reset Preț';
$lang['AdminMain.!error.unsupported_domain'] = 'Numele de domeniu nu este acceptat.';
$lang['AdminMain.!success.service_edited'] = 'Domeniul a fost actualizat cu succes!';
$lang['AdminMain.!success.domain_add'] = 'Domeniul a fost adăugat cu succes!';
$lang['AdminMain.!success.domain_transfer'] = 'Domeniul a fost transferat cu succes!';
$lang['AdminMain.!success.domain_register'] = 'Domeniul a fost înregistrat cu succes!';
$lang['AdminMain.!success.domains_unparented'] = 'Domeniile selectate au fost eliminate din serviciile lor părintești și prețul a fost resetat cu succes!';
$lang['AdminMain.getfilters.field_service_meta'] = 'Nume de domeniu';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = 'Orice';
$lang['AdminMain.domains.action.field_client'] = 'Client';
$lang['AdminMain.domains.action.field_nameservers'] = 'Nameservere';
$lang['AdminMain.domains.action.field_years'] = 'Ani';
$lang['AdminMain.index.field_actionsubmit'] = 'Trimiteți';
$lang['AdminMain.index.domain_push_to_client'] = 'Push to Client';
$lang['AdminMain.index.update_nameservers'] = 'Actualizarea Nameserverelor';
$lang['AdminMain.index.domain_renewal'] = 'Reînnoiți domeniul';
$lang['AdminMain.index.change_auto_renewal'] = 'Schimbarea reînnoirii auto';
$lang['AdminMain.index.text_off'] = 'Off';
$lang['AdminMain.index.text_on'] = 'Pe';
$lang['AdminMain.index.text_never'] = 'Niciodată';
$lang['AdminMain.index.no_results'] = 'Nu există servicii cu acest statut.';
$lang['AdminMain.index.confirm_delete'] = 'Sunteți sigur că doriți să ștergeți acest serviciu?';
$lang['AdminMain.index.option_delete'] = 'Ștergeți';
$lang['AdminMain.index.option_manage'] = 'Gestionați';
$lang['AdminMain.index.option_parent'] = 'Părinte';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = 'Domeniu nou';
$lang['AdminMain.index.category_canceled'] = 'Anulat';
$lang['AdminMain.index.category_suspended'] = 'Suspendat';
$lang['AdminMain.index.category_pending'] = 'În așteptare';
$lang['AdminMain.index.category_active'] = 'Activ';
$lang['AdminMain.index.heading_options'] = 'Opțiuni';
$lang['AdminMain.index.heading_datecanceled'] = 'Data anulării';
$lang['AdminMain.index.heading_datesuspended'] = 'Data suspendării';
$lang['AdminMain.index.heading_dateexpires'] = 'Data expirării';
$lang['AdminMain.index.heading_daterenews'] = 'Data reînnoiește';
$lang['AdminMain.index.heading_datecreated'] = 'Data creării';
$lang['AdminMain.index.heading_term'] = 'Termen';
$lang['AdminMain.index.heading_domain'] = 'Domeniu';
$lang['AdminMain.index.heading_status'] = 'Stare';
$lang['AdminMain.index.heading_addons'] = 'Suplimente';
$lang['AdminMain.index.boxtitle_domains'] = 'Domenii';
$lang['AdminMain.index.page_title'] = 'Client #%1$s Domenii';
$lang['AdminMain.!success.domains_pushed'] = 'Domeniile selectate au fost transferate cu succes către noul client.';
$lang['AdminMain.!success.update_nameservers'] = 'Serverele de nume de domeniu au fost actualizate!';
$lang['AdminMain.!success.domain_renewal'] = 'Domeniul a fost reînnoit!';
$lang['AdminMain.!success.change_auto_renewal'] = 'Reînnoirea automată a domeniului a fost actualizată!';
$lang['AdminMain.edit.text_registration_date'] = 'Data înregistrării:';
$lang['AdminMain.index.text_date_added'] = 'Data adăugării:';
$lang['AdminMain.index.heading_dateregistration'] = 'Data înregistrării';
$lang['AdminMain.index.heading_registrar'] = 'Registrator';
$lang['AdminMain.!success.domain_registrar_updated'] = 'Registrul de domenii a fost actualizat!';
$lang['AdminMain.edit.field_registration_date'] = 'Modificarea datei de înregistrare';
$lang['AdminMain.edit.field_expiration_date'] = 'Modificarea datei de expirare';
$lang['AdminMain.!success.change_registration_date'] = 'Data înregistrării domeniului a fost actualizată!';
$lang['AdminMain.!success.change_expiration_date'] = 'Data de expirare a domeniului a fost actualizată!';
